==> sqliteman-0.99-20070403.tar.gz: sqliteman-0.99/sqliteman/doc/en/cmake_install.cmake <==
# Install script for directory: /home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/home/pvanek/sqliteman-svn/TESTBUILD")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "RELEASE")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/menu.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/index.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/license.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/sqlite.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-run.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-file.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/troubleshooting.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-prefs.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-context.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-database.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/sqleditor.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-system.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/results.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/main_window.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/create_table.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/sqleditor.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/results.png")

==> sqliteman-0.99-20070509.tar.gz: sqliteman-0.99/sqliteman/doc/en/cmake_install.cmake <==
# Install script for directory: /home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/home/pvanek/sqliteman-svn/TESTBUILD")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "Debug")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/menu.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/index.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/license.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/sqlite.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-run.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-file.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/troubleshooting.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-prefs.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-context.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-database.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/sqleditor.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/usage-system.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/results.html")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/main_window.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/create_table.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/sqleditor.png")
FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/sqliteman/doc/en" TYPE FILE FILES "/home/pvanek/sqliteman-svn/sqliteman/Sqliteman/sqliteman/doc/en/results.png")
